@@ -24,7 +24,7 @@ from .api_pb2 import (  # type: ignore
     BluetoothLEAdvertisementResponse,
     BluetoothScannerStateResponse,
     CameraImageResponse,
-    HomeassistantServiceResponse,
+    HomeassistantActionRequest,
     SubscribeHomeAssistantStateResponse,
 )
 from .connection import ConnectionParams
@@ -85,7 +85,7 @@ def on_state_msg(
 
 def on_home_assistant_service_response(
     on_service_call: Callable[[HomeassistantServiceCall], None],
-    msg: HomeassistantServiceResponse,
+    msg: HomeassistantActionRequest,
 ) -> None:
     on_service_call(HomeassistantServiceCall.from_pb(msg))
 
@@ -230,6 +230,7 @@ class APIClientBase:
         expected_name: str_ | None = None,
         addresses: list[str_] | None = None,
         expected_mac: str_ | None = None,
+        timezone: str_ | None = None,
     ) -> None:
         """Create a client, this object is shared across sessions.
 
@@ -252,6 +253,9 @@ class APIClientBase:
         :param expected_mac: Optional MAC address to check against the device.
             The format should be lower case without : or - separators.
             Example: 00:aa:22:33:44:55 -> 00aa22334455
+        :param timezone: Optional IANA timezone name to send to ESPHome devices.
+            If not provided, the system timezone will be detected automatically.
+            Example: 'America/Chicago' or 'Europe/London'
         """
         self._debug_enabled = _LOGGER.isEnabledFor(logging.DEBUG)
         self._params = ConnectionParams(
@@ -267,6 +271,7 @@ class APIClientBase:
             noise_psk=_stringify_or_none(noise_psk) or None,
             expected_name=_stringify_or_none(expected_name) or None,
             expected_mac=_stringify_or_none(expected_mac) or None,
+            timezone=_stringify_or_none(timezone) or None,
         )
         self._connection: APIConnection | None = None
         self.cached_name: str | None = None
@@ -296,6 +301,21 @@ class APIClientBase:
     def address(self) -> str:
         return self._params.addresses[0]
 
+    @property
+    def port(self) -> int:
+        return self._params.port
+
+    @property
+    def noise_psk(self) -> str | None:
+        return self._params.noise_psk
+
+    @property
+    def connected_address(self) -> str | None:
+        """Return the address we are currently connected to, or None if not connected."""
+        if self._connection is None:
+            return None
+        return self._connection.connected_address
+
     @property
     def api_version(self) -> APIVersion | None:
         if self._connection is None:
