@@ -22,8 +22,8 @@ import aioesphomeapi.host_resolver as hr
 from ._frame_helper.noise import APINoiseFrameHelper
 from ._frame_helper.plain_text import APIPlaintextFrameHelper
 from .api_pb2 import (  # type: ignore
-    ConnectRequest,
-    ConnectResponse,
+    AuthenticationRequest,
+    AuthenticationResponse,
     DisconnectRequest,
     DisconnectResponse,
     GetTimeRequest,
@@ -50,7 +50,7 @@ from .core import (
     UnhandledAPIConnectionError,
 )
 from .model import APIVersion, message_types_to_names
-from .timezone import get_local_timezone
+from .timezone import get_timezone
 from .util import asyncio_timeout
 from .zeroconf import ZeroconfManager
 
@@ -68,7 +68,7 @@ DISCONNECT_REQUEST_MESSAGE = DisconnectRequest()
 DISCONNECT_RESPONSE_MESSAGES = (DisconnectResponse(),)
 PING_REQUEST_MESSAGES = (PingRequest(),)
 PING_RESPONSE_MESSAGES = (PingResponse(),)
-NO_PASSWORD_CONNECT_REQUEST = ConnectRequest()
+NO_PASSWORD_AUTH_REQUEST = AuthenticationRequest()
 
 PROTO_TO_MESSAGE_TYPE: dict[
     type[message.Message], tuple[int, Callable[[message.Message], bytes]]
@@ -122,6 +122,7 @@ class ConnectionParams:
     noise_psk: str | None
     expected_name: str | None
     expected_mac: str | None
+    timezone: str | None = None
 
 
 class ConnectionState(enum.Enum):
@@ -471,36 +472,25 @@ class APIConnection:
         messages = [make_hello_request(self._params.client_info)]
         msg_types = [HelloResponse]
         if login:
-            messages.append(self._make_connect_request())
-            if self._params.password:
-                # Only wait for ConnectResponse if we actually have
-                # a password to send, but we will still register
-                # a handler for a ConnectResponse just in case
-                # the device has a password but we don't expect it
-                msg_types.append(ConnectResponse)
+            messages.append(self._make_auth_request())
+            # Never wait for AuthenticationResponse - the device will either
+            # send it immediately if authentication fails, or not send it at all
+            # if it doesn't support password authentication
 
         responses = await self.send_messages_await_response_complex(
             tuple(messages),
             None,
             lambda resp: type(resp)  # pylint: disable=unidiomatic-typecheck
-            is msg_types[-1],
+            is HelloResponse,  # Only wait for HelloResponse
             tuple(msg_types),
             CONNECT_REQUEST_TIMEOUT,
         )
 
         resp = responses.pop(0)
         self._process_hello_resp(resp)
-        if login and self._params.password:
-            login_response = responses.pop(0)
-            self._process_login_response(login_response)
 
-    def _process_login_response(self, login_response: ConnectResponse) -> None:
-        """Process a ConnectResponse."""
-        if login_response.invalid_password:
-            raise InvalidAuthAPIError("Invalid password!")
-
-    def _handle_login_response(self, login_response: ConnectResponse) -> None:
-        """Handle a ConnectResponse."""
+    def _handle_login_response(self, login_response: AuthenticationResponse) -> None:
+        """Handle a AuthenticationResponse."""
         if login_response.invalid_password:
             self.report_fatal_error(InvalidAuthAPIError("Invalid password!"))
 
@@ -700,7 +690,9 @@ class APIConnection:
         """Finish the connection process."""
         # Cache timezone before registering handlers to ensure it's available
         # when GetTimeRequest is received
-        self._cached_timezone = await get_local_timezone()
+        # Use provided timezone from params (converted from IANA to POSIX if needed),
+        # or fall back to local timezone detection
+        self._cached_timezone = await get_timezone(self._params.timezone)
         # Register internal handlers before
         # connecting the helper so we can ensure
         # we handle any messages that are received immediately
@@ -752,11 +744,11 @@ class APIConnection:
             or state is CONNECTION_STATE_CONNECTED
         )
 
-    def _make_connect_request(self) -> ConnectRequest:
-        """Make a ConnectRequest."""
+    def _make_auth_request(self) -> AuthenticationRequest:
+        """Make a AuthenticationRequest."""
         if self._params.password is not None:
-            return ConnectRequest(password=self._params.password)
-        return NO_PASSWORD_CONNECT_REQUEST
+            return AuthenticationRequest(password=self._params.password)
+        return NO_PASSWORD_AUTH_REQUEST
 
     def send_message(self, msg: message.Message) -> None:
         """Send a message to the remote."""
@@ -786,8 +778,11 @@ class APIConnection:
                     MessageToDict(msg) if _WIN32 else msg,
                 )
 
-        if TYPE_CHECKING:
-            assert self._frame_helper is not None
+        # Check frame_helper is not None to prevent segfault in Cython code
+        if self._frame_helper is None:
+            raise self._fatal_exception or ConnectionNotEstablishedAPIError(
+                f"Connection is closed ({self.connection_state})"
+            )
 
         try:
             self._frame_helper.write_packets(packets, self._debug_enabled)
@@ -1043,7 +1038,7 @@ class APIConnection:
             self._handle_get_time_request_internal, (GetTimeRequest,)
         )
         self._add_message_callback_without_remove(
-            self._handle_login_response, (ConnectResponse,)
+            self._handle_login_response, (AuthenticationResponse,)
         )
 
     def _handle_disconnect_request_internal(  # pylint: disable=unused-argument
@@ -1094,11 +1089,12 @@ class APIConnection:
                     )
 
         self._expected_disconnect = True
-        if self._handshake_complete:
+        if self._handshake_complete and self._frame_helper is not None:
             # We still want to send a disconnect request even
             # if the hello phase isn't finished to ensure we
             # the esp will clean up the connection as soon
             # as possible.
+            # But skip if frame_helper is None (connection already cleaned up)
             try:
                 await self.send_message_await_response(
                     DISCONNECT_REQUEST_MESSAGE,
@@ -1113,9 +1109,10 @@ class APIConnection:
     def force_disconnect(self) -> None:
         """Forcefully disconnect from the API."""
         self._expected_disconnect = True
-        if self._handshake_complete:
+        if self._handshake_complete and self._frame_helper is not None:
             # Still try to tell the esp to disconnect gracefully
             # but don't wait for it to finish
+            # But skip if frame_helper is None (connection already cleaned up)
             try:
                 self.send_messages((DISCONNECT_REQUEST_MESSAGE,))
             except APIConnectionError:
