@@ -125,6 +125,20 @@ class VoiceAssistantFeature(enum.IntFlag):
     START_CONVERSATION = 1 << 5
 
 
+class ZWaveProxyFeature(enum.IntFlag):
+    ENABLED = 1 << 0
+
+
+class ZWaveProxyRequestType(APIIntEnum):
+    SUBSCRIBE = 0
+    UNSUBSCRIBE = 1
+
+
+@_frozen_dataclass_decorator
+class ZWaveProxyRequest(APIModelBase):
+    type: ZWaveProxyRequestType = ZWaveProxyRequestType.SUBSCRIBE
+
+
 class VoiceAssistantSubscriptionFlag(enum.IntFlag):
     API_AUDIO = 1 << 2
 
@@ -186,6 +200,8 @@ class DeviceInfo(APIModelBase):
     voice_assistant_feature_flags: int = 0
     legacy_bluetooth_proxy_version: int = 0
     bluetooth_proxy_feature_flags: int = 0
+    zwave_proxy_feature_flags: int = 0
+    zwave_home_id: int = 0
     suggested_area: str = ""
     bluetooth_mac_address: str = ""
     api_encryption_supported: bool = False
@@ -225,6 +241,9 @@ class DeviceInfo(APIModelBase):
             return flags
         return self.voice_assistant_feature_flags
 
+    def zwave_proxy_feature_flags_compat(self, api_version: APIVersion) -> int:
+        return self.zwave_proxy_feature_flags
+
 
 class EntityCategory(APIIntEnum):
     NONE = 0
@@ -1276,6 +1295,11 @@ class BluetoothLEAdvertisement:
         )
 
 
+@_frozen_dataclass_decorator
+class ZWaveProxyFrame(APIModelBase):
+    data: bytes = field(default_factory=bytes)  # pylint: disable=invalid-field-call
+
+
 @_frozen_dataclass_decorator
 class BluetoothDeviceConnection(APIModelBase):
     address: int = 0
@@ -1552,6 +1576,27 @@ class VoiceAssistantWakeWord(APIModelBase):
         return ret
 
 
+@_frozen_dataclass_decorator
+class VoiceAssistantExternalWakeWord(APIModelBase):
+    id: str
+    wake_word: str
+    trained_languages: list[str]
+    model_type: str
+    model_size: int
+    model_hash: str
+    url: str
+
+    @classmethod
+    def convert_list(cls, value: list[Any]) -> list[VoiceAssistantExternalWakeWord]:
+        ret = []
+        for x in value:
+            if isinstance(x, dict):
+                ret.append(VoiceAssistantExternalWakeWord.from_dict(x))
+            else:
+                ret.append(VoiceAssistantExternalWakeWord.from_pb(x))
+        return ret
+
+
 @_frozen_dataclass_decorator
 class VoiceAssistantConfigurationResponse(APIModelBase):
     available_wake_words: list[VoiceAssistantWakeWord] = converter_field(
@@ -1563,7 +1608,9 @@ class VoiceAssistantConfigurationResponse(APIModelBase):
 
 @_frozen_dataclass_decorator
 class VoiceAssistantConfigurationRequest(APIModelBase):
-    pass
+    external_wake_words: list[VoiceAssistantExternalWakeWord] = converter_field(
+        default_factory=list, converter=VoiceAssistantExternalWakeWord.convert_list
+    )
 
 
 @_frozen_dataclass_decorator
